polyfemos.util.randomizer — polyfemos 0.3.29 documentation

# polyfemos.util.randomizer

A small module for generating ascii secret keys.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.util.randomizer.` `generate_secret_key`()
  Return type

    str

  Returns

    44 bytes long urlsafe secret key

`polyfemos.util.randomizer.` `get_secret_key`()

  Generates and prints a secret key